@@ -65,6 +65,12 @@
 
 	-	use some explicit type casting to avoid compiler warnings
 	-	clear some backward compatability flags for 0.93.10
+
+	2001-04-07  ap
+	-	implemented flag CHECK_TJ_OVERFLOW to check for huffman table overflow
+
+	2001-05-02  ap
+	-	bug fix: outer_loop() - correct handling of flag tjBitOverflow2
 */
 
 
@@ -83,6 +89,8 @@
 #define		ORG_OUTER_LOOP			0   /* 0 = differ between marked as "been amplified" and "should be amplified" */
 #define		ORG_HIGHEST_SFB			1   /* 0 = cut off highest frequencies (in last scale factor band) */
 
+#define		CHECK_TJ_OVERFLOW		1   /* 1 = check for huffman table overflow */
+
 
 
 
@@ -240,7 +248,7 @@ int						*scalefac_band_short;
 
 int						fInit_iteration_loop;
 
-#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT
+#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT || CHECK_TJ_OVERFLOW
 int						tjBitOverflow2;
 #endif
 
@@ -875,19 +883,29 @@ static	int				outer_loop
 			so why quantize the whole area?
 		*/
 		partial_quantize ();
-#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT
-assert (!tjBitOverflow2);
+#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT || CHECK_TJ_OVERFLOW
+		if (tjBitOverflow2)
+			bits = infinity;
+		else
+			bits = count_bits ();
+#else
+		bits = count_bits ();
 #endif
-		bits = count_bits();
 
 		while (bits > huff_bits)
 		{
 			cod_info->quantizerStepSize += 1.0;
+#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT || CHECK_TJ_OVERFLOW
+			tjBitOverflow2 = FALSE;
+			quantize ();
+			if (tjBitOverflow2)
+				bits = infinity;
+			else
+				bits = count_bits ();
+#else
 			quantize ();
-#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT
-assert (!tjBitOverflow2);
-#endif
 			bits = count_bits ();
+#endif
 		}
 
 #if !ORG_OUTER_LOOP
@@ -1315,7 +1333,7 @@ static	int INLINE		cutting_crew (FLOAT in)
 
 	retVal = (int) (in + 0.4054);
 
-#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT
+#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT || CHECK_TJ_OVERFLOW
 	if (retVal > 8191+14)
 		tjBitOverflow2 = TRUE;
 #endif
@@ -1732,7 +1750,7 @@ static	int				bin_search_StepSize
 		next = top + (bot - top) / 2;
 		cod_info->quantizerStepSize = next;
 
-#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT
+#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT || CHECK_TJ_OVERFLOW
 		tjBitOverflow2 = FALSE;
 		quantize ();
 		if (tjBitOverflow2)
@@ -1756,7 +1774,7 @@ static	int				bin_search_StepSize
 	if (bits > desired_rate)
 	{
 		cod_info->quantizerStepSize = next+1;
-#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT
+#if ORG_BINARY_SEARCH || ORG_QUANTANF_INIT || CHECK_TJ_OVERFLOW
 		tjBitOverflow2 = FALSE;
 		quantize ();
 assert(! tjBitOverflow2);
