@@ -329,7 +329,7 @@ int						main (int argc, char* argv[])
 	if (!wantedQuiet)
 	{
 		fprintf (textout, "\n");
-		fprintf (textout, "BladeEnc 0.94.0    (c) Tord Jansson            Homepage: http://bladeenc.mp3.no\n");
+		fprintf (textout, "BladeEnc 0.94.2    (c) Tord Jansson            Homepage: http://bladeenc.mp3.no\n");
 		fprintf (textout, "===============================================================================\n");
 		fprintf (textout, "BladeEnc is free software, distributed under the Lesser General Public License.\n");
 		fprintf (textout, "See the file COPYING, BladeEnc's homepage or www.fsf.org for more details.\n");
@@ -642,13 +642,15 @@ int						main (int argc, char* argv[])
 		fprintf (textout, "All operations completed. Total encoding time: %02d:%02d:%02d\n",
 		         (int) seconds/3600, (int)(seconds/60)%60, (int) seconds%60);
 
+#ifdef	WAIT_KEY
 		if (!wantedQuit)
-		{
+		{			
 			fprintf (textout, "Press ENTER to exit...");
 			fflush( textout );
 			be_getch ();
 			fprintf (textout, "\n");
 		}
+#endif
 	}
 
 	return 0;
@@ -662,6 +664,7 @@ int						main (int argc, char* argv[])
 
 void					quit (int returnValue)
 {
+#ifdef	WAIT_KEY
 	if (!wantedQuit)
 	{
 		fprintf (textout, "Press ENTER to exit...");
@@ -669,6 +672,7 @@ void					quit (int returnValue)
 		be_getch ();
 		fprintf (textout, "\n");
 	}
+#endif
 #if SYSTEM == MAC_OS
 	throw returnValue;
 #else
